module UserManagementRails
  class InstallGenerator < Rails::Generators::Base

    desc <<-DESC.strip_heredoc
        Create UserManagementRails boilerplate (controller and view) in your app folder.

        Required Flags:

        Use -r to specify your RingCaptcha app key.
        Use -u to specify your UM key (for login mode only).

        Optional Flags:

        Use -m to specify login mode (options: password, otp).

        If you do no specify a mode, password mode will be created by default.
        For example:

          rails generate user_management_rails:install users -m=password -r=XXXXXX -u=XXXXX

        This will create a controller class at app/controllers/user_management_controller.rb like this:

          class UserManagementController < ApplicationController
            content...
          end
    DESC

    source_root File.expand_path("../../templates", __FILE__)
    class_option :ringcaptcha_key, required: true, aliases: "-r", type: :string,
        desc: "Specify the RingCaptcha app key."
    class_option :um_key, required: true, aliases: "-u", type: :string,
        desc: "Specify the User Management key."
    class_option :mode, aliases: "-m", type: :string, default: 'otp',
        desc: "Specify the King Authr mode. Possible values: [otp|password]"

    def add_initializer
      template "user_management_initializer.rb", "config/initializers/user_management.rb"
    end

    def create_controller
      template "controllers/user_management_controller.rb",
                   "app/controllers/user_management_controller.rb"
    end

    def create_view
      template "views/signup.html.erb",
                   "app/views/user_management/signup.html.erb"
      template "views/login.html.erb",
                   "app/views/user_management/login.html.erb"
      template "views/home.html.erb",
                   "app/views/user_management/home.html.erb"
    end

    def add_routes
      route "root 'user_management#signup'"
      route "post '/logout', to: 'user_management#logout'"
      route "get '/login', to: 'user_management#login'"
      route "get '/home', to: 'user_management#home'"
      route "mount UserManagementRails::Engine, at: '/'"
    end

    def show_readme
      readme "README" if behavior == :invoke
    end

  end
end
